phoneapp/phoneuistates/src/cphonetwosinglesandwaiting.cpp
branchRCL_3
changeset 14 24062c24fe38
parent 9 8871b09be73b
child 15 2a26698d78ba
--- a/phoneapp/phoneuistates/src/cphonetwosinglesandwaiting.cpp	Fri Feb 19 22:50:26 2010 +0200
+++ b/phoneapp/phoneuistates/src/cphonetwosinglesandwaiting.cpp	Fri Mar 12 15:42:40 2010 +0200
@@ -238,7 +238,7 @@
     // Effect is shown when dialer exist.
     
     TBool effectStarted ( EFalse );
-    if ( !NeedToSendToBackgroundL())
+    if ( !NeedToReturnToForegroundAppL() )
         {
         BeginTransEffectLC( ENumberEntryOpen );
         effectStarted = ETrue;   
@@ -282,9 +282,9 @@
     if ( IsNumberEntryUsedL() )
         {
         // Go to background if necessary
-        if ( NeedToSendToBackgroundL() )
+        if ( NeedToReturnToForegroundAppL() )
             {
             // Return phone to the background if send to background is needed.
             iViewCommandHandle->ExecuteCommandL( EPhoneViewSendToBackground );
 
             iViewCommandHandle->ExecuteCommandL( EPhoneViewSetControlAndVisibility );
@@ -302,9 +302,9 @@
         // Set Two singles softkeys
         UpdateCbaL( EPhoneCallHandlingNewCallSwapCBA );
 	    
         // If numberentry is not open just check NeedToSendToBackgroundL and 
         // sendbackround if needed.
-        if ( NeedToSendToBackgroundL() )
+        if ( NeedToReturnToForegroundAppL() )
             {
             // Return phone to the background if send to background is needed.
             iViewCommandHandle->ExecuteCommandL( EPhoneViewSendToBackground );
@@ -398,7 +398,8 @@
     TPhoneCmdParamBoolean booleanParam;
     booleanParam.SetBoolean( EFalse );
     iViewCommandHandle->ExecuteCommandL( 
-        EPhoneViewSetNeedToSendToBackgroundStatus, &booleanParam );
+         EPhoneViewSetNeedToReturnToForegroundAppStatus,
+         &booleanParam );
         
     EndUiUpdate();
     // Go to Conference And Waiting state
@@ -282,9 +282,9 @@
             {
-            // Return phone to the background if send to background is needed.
+            // Return phone to the background if menu application is needed to foreground.
             iViewCommandHandle->ExecuteCommandL( EPhoneViewSendToBackground );
 
@@ -302,9 +302,9 @@
         UpdateCbaL( EPhoneCallHandlingNewCallSwapCBA );
 	    
-        // If numberentry is not open just check NeedToSendToBackgroundL and 
+        // If numberentry is not open just check NeedToReturnToForegroundAppL and 
         // sendbackround if needed.